aboutsummaryrefslogtreecommitdiffstats
path: root/make/scripts
diff options
context:
space:
mode:
authorSven Gothel <[email protected]>2010-12-13 02:26:48 +0100
committerSven Gothel <[email protected]>2010-12-13 02:26:48 +0100
commit84a76425dd10933a7ad033920a1e0ce12a2a107b (patch)
tree3f4b1c3d61edb539232bf6bbcf1e673cc011b1d4 /make/scripts
parent519776330c78e296d9868e959ddc64d00acac496 (diff)
Cleanup test/junit structure. com.jogamp.test -> com.jogamp.opengl.text; Compile posted Issue* Bug* snippets
Diffstat (limited to 'make/scripts')
-rw-r--r--make/scripts/tests-x32.bat52
-rw-r--r--make/scripts/tests-x64.bat70
-rw-r--r--make/scripts/tests.sh100
3 files changed, 111 insertions, 111 deletions
diff --git a/make/scripts/tests-x32.bat b/make/scripts/tests-x32.bat
index f1ea96484..618587c72 100644
--- a/make/scripts/tests-x32.bat
+++ b/make/scripts/tests-x32.bat
@@ -1,32 +1,32 @@
scripts\java-win32-dbg.bat com.jogamp.newt.opengl.GLWindow
REM scripts\java-win32-dbg.bat com.jogamp.newt.opengl.GLWindow
-REM scripts\java-win32-dbg.bat com.jogamp.test.junit.jogl.acore.TestGLProfile01NEWT
-REM scripts\java-win32-dbg.bat com.jogamp.test.junit.jogl.demos.gl2.gears.newt.TestGearsNEWT -time 30000
-REM scripts\java-win32-dbg.bat com.jogamp.test.junit.jogl.newt.TestSwingAWTRobotUsageBeforeJOGLInitBug411
-REM scripts\java-win32-dbg.bat com.jogamp.test.junit.jogl.glsl.TestTransformFeedbackVaryingsBug407NEWT
-REM scripts\java-win32.bat com.jogamp.test.junit.jogl.glsl.TestGLSLSimple01NEWT -time 2000
+REM scripts\java-win32-dbg.bat com.jogamp.opengl.test.junit.jogl.acore.TestGLProfile01NEWT
+REM scripts\java-win32-dbg.bat com.jogamp.opengl.test.junit.jogl.demos.gl2.gears.newt.TestGearsNEWT -time 30000
+REM scripts\java-win32-dbg.bat com.jogamp.opengl.test.junit.jogl.newt.TestSwingAWTRobotUsageBeforeJOGLInitBug411
+REM scripts\java-win32-dbg.bat com.jogamp.opengl.test.junit.jogl.glsl.TestTransformFeedbackVaryingsBug407NEWT
+REM scripts\java-win32.bat com.jogamp.opengl.test.junit.jogl.glsl.TestGLSLSimple01NEWT -time 2000
-REM scripts\java-win32-dbg.bat com.jogamp.test.junit.newt.TestParenting01AWT
-REM scripts\java-win32-dbg.bat com.jogamp.test.junit.newt.parenting.TestParenting01cAWT -time 50000
-REM scripts\java-win32-dbg.bat com.jogamp.test.junit.newt.TestListenerCom01AWT
-REM scripts\java-win32-dbg.bat com.jogamp.test.junit.newt.parenting.TestParenting01NEWT
+REM scripts\java-win32-dbg.bat com.jogamp.opengl.test.junit.newt.TestParenting01AWT
+REM scripts\java-win32-dbg.bat com.jogamp.opengl.test.junit.newt.parenting.TestParenting01cAWT -time 50000
+REM scripts\java-win32-dbg.bat com.jogamp.opengl.test.junit.newt.TestListenerCom01AWT
+REM scripts\java-win32-dbg.bat com.jogamp.opengl.test.junit.newt.parenting.TestParenting01NEWT
-REM scripts\java-win32-dbg.bat com.jogamp.test.junit.newt.TestGLWindows01NEWT
-REM scripts\java-win32-dbg.bat com.jogamp.test.junit.newt.TestGLWindows02NEWTAnimated
-REM scripts\java-win32-dbg.bat com.jogamp.test.junit.newt.parenting.TestParenting01NEWT
-REM scripts\java-win32-dbg.bat com.jogamp.test.junit.newt.TestFocus02SwingAWTRobot
-REM scripts\java-win32-dbg.bat com.jogamp.test.junit.newt.TestFocus01SwingAWTRobot
-REM scripts\java-win32-dbg.bat com.jogamp.test.junit.nativewindow.TestRecursiveToolkitLockCORE
-REM scripts\java-win32-dbg.bat com.jogamp.test.junit.newt.parenting.TestParenting03AWT -time 100000
+REM scripts\java-win32-dbg.bat com.jogamp.opengl.test.junit.newt.TestGLWindows01NEWT
+REM scripts\java-win32-dbg.bat com.jogamp.opengl.test.junit.newt.TestGLWindows02NEWTAnimated
+REM scripts\java-win32-dbg.bat com.jogamp.opengl.test.junit.newt.parenting.TestParenting01NEWT
+REM scripts\java-win32-dbg.bat com.jogamp.opengl.test.junit.newt.TestFocus02SwingAWTRobot
+REM scripts\java-win32-dbg.bat com.jogamp.opengl.test.junit.newt.TestFocus01SwingAWTRobot
+REM scripts\java-win32-dbg.bat com.jogamp.opengl.test.junit.nativewindow.TestRecursiveToolkitLockCORE
+REM scripts\java-win32-dbg.bat com.jogamp.opengl.test.junit.newt.parenting.TestParenting03AWT -time 100000
-REM scripts\java-win32.bat com.jogamp.test.junit.newt.TestFocus02SwingAWTRobot
-REM scripts\java-win32-dbg.bat com.jogamp.test.junit.newt.TestScreenMode00NEWT
-REM scripts\java-win32-dbg.bat com.jogamp.test.junit.newt.TestScreenMode01NEWT
-REM scripts\java-win32-dbg.bat com.jogamp.test.junit.newt.TestScreenMode02NEWT
+REM scripts\java-win32.bat com.jogamp.opengl.test.junit.newt.TestFocus02SwingAWTRobot
+REM scripts\java-win32-dbg.bat com.jogamp.opengl.test.junit.newt.TestScreenMode00NEWT
+REM scripts\java-win32-dbg.bat com.jogamp.opengl.test.junit.newt.TestScreenMode01NEWT
+REM scripts\java-win32-dbg.bat com.jogamp.opengl.test.junit.newt.TestScreenMode02NEWT
-REM scripts\java-win32-dbg.bat com.jogamp.test.junit.newt.TestDisplayLifecycle01NEWT
-REM scripts\java-win32-dbg.bat com.jogamp.test.junit.newt.parenting.TestParenting01NEWT
-REM scripts\java-win32-dbg.bat com.jogamp.test.junit.newt.parenting.TestParenting02NEWT
-REM scripts\java-win32.bat com.jogamp.test.junit.newt.TestCloseNewtAWT
-REM scripts\java-win32-dbg.bat com.jogamp.test.junit.jogl.caps.TestMultisampleAWT -time 10000
-REM scripts\java-win32-dbg.bat com.jogamp.test.junit.jogl.caps.TestMultisampleNEWT -time 10000
+REM scripts\java-win32-dbg.bat com.jogamp.opengl.test.junit.newt.TestDisplayLifecycle01NEWT
+REM scripts\java-win32-dbg.bat com.jogamp.opengl.test.junit.newt.parenting.TestParenting01NEWT
+REM scripts\java-win32-dbg.bat com.jogamp.opengl.test.junit.newt.parenting.TestParenting02NEWT
+REM scripts\java-win32.bat com.jogamp.opengl.test.junit.newt.TestCloseNewtAWT
+REM scripts\java-win32-dbg.bat com.jogamp.opengl.test.junit.jogl.caps.TestMultisampleAWT -time 10000
+REM scripts\java-win32-dbg.bat com.jogamp.opengl.test.junit.jogl.caps.TestMultisampleNEWT -time 10000
diff --git a/make/scripts/tests-x64.bat b/make/scripts/tests-x64.bat
index 4f227e14a..a778217b7 100644
--- a/make/scripts/tests-x64.bat
+++ b/make/scripts/tests-x64.bat
@@ -1,43 +1,43 @@
REM scripts\java-win64-dbg.bat com.jogamp.newt.opengl.GLWindow
REM scripts\java-win64-dbg.bat javax.media.opengl.awt.GLCanvas
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.jogl.awt.TestAWT01GLn
-REM scripts\java-win64.bat com.jogamp.test.junit.jogl.awt.TestSwingAWT01GLn
-REM scripts\java-win64.bat com.jogamp.test.junit.jogl.acore.TestSharedContextListAWT -time 5000
-REM scripts\java-win64.bat com.jogamp.test.junit.jogl.acore.TestSharedContextListNEWT -time 5000
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.jogl.acore.TestGLProfile01NEWT
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.jogl.awt.TestAWT01GLn
+REM scripts\java-win64.bat com.jogamp.opengl.test.junit.jogl.awt.TestSwingAWT01GLn
+REM scripts\java-win64.bat com.jogamp.opengl.test.junit.jogl.acore.TestSharedContextListAWT -time 5000
+REM scripts\java-win64.bat com.jogamp.opengl.test.junit.jogl.acore.TestSharedContextListNEWT -time 5000
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.jogl.acore.TestGLProfile01NEWT
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.jogl.demos.gl2.gears.newt.TestGearsNEWT -time 30000
-scripts\java-win64-dbg.bat com.jogamp.test.junit.jogl.demos.gl2.gears.TestGearsGLJPanelAWT -time 5000
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.jogl.awt.TestAWT03GLCanvasRecreate01
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.jogl.newt.TestSwingAWTRobotUsageBeforeJOGLInitBug411
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.jogl.glsl.TestTransformFeedbackVaryingsBug407NEWT
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.jogl.glsl.TestGLSLSimple01NEWT -time 2000
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.jogl.demos.gl2.gears.newt.TestGearsNEWT -time 30000
+scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.jogl.demos.gl2.gears.TestGearsGLJPanelAWT -time 5000
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.jogl.awt.TestAWT03GLCanvasRecreate01
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.jogl.newt.TestSwingAWTRobotUsageBeforeJOGLInitBug411
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.jogl.glsl.TestTransformFeedbackVaryingsBug407NEWT
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.jogl.glsl.TestGLSLSimple01NEWT -time 2000
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.newt.TestParenting01AWT
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.newt.parenting.TestParenting01cAWT -time 50000
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.newt.TestListenerCom01AWT
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.newt.parenting.TestParenting01NEWT
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.newt.TestParenting01AWT
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.newt.parenting.TestParenting01cAWT -time 50000
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.newt.TestListenerCom01AWT
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.newt.parenting.TestParenting01NEWT
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.newt.TestGLWindows01NEWT
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.newt.TestGLWindows02NEWTAnimated
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.newt.parenting.TestParenting01NEWT
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.newt.TestFocus02SwingAWTRobot
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.newt.TestFocus01SwingAWTRobot
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.nativewindow.TestRecursiveToolkitLockCORE
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.newt.parenting.TestParenting03AWT -time 100000
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.newt.TestGLWindows01NEWT
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.newt.TestGLWindows02NEWTAnimated
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.newt.parenting.TestParenting01NEWT
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.newt.TestFocus02SwingAWTRobot
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.newt.TestFocus01SwingAWTRobot
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.nativewindow.TestRecursiveToolkitLockCORE
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.newt.parenting.TestParenting03AWT -time 100000
-REM scripts\java-win64.bat com.jogamp.test.junit.newt.TestFocus02SwingAWTRobot
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.newt.TestScreenMode00NEWT
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.newt.TestScreenMode01NEWT
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.newt.TestScreenMode02NEWT
+REM scripts\java-win64.bat com.jogamp.opengl.test.junit.newt.TestFocus02SwingAWTRobot
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.newt.TestScreenMode00NEWT
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.newt.TestScreenMode01NEWT
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.newt.TestScreenMode02NEWT
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.newt.TestDisplayLifecycle01NEWT
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.newt.parenting.TestParenting01NEWT
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.newt.parenting.TestParenting02NEWT
-REM scripts\java-win64.bat com.jogamp.test.junit.newt.TestCloseNewtAWT
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.jogl.caps.TestMultisampleAWT -time 10000
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.jogl.caps.TestMultisampleNEWT -time 10000
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.newt.TestDisplayLifecycle01NEWT
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.newt.parenting.TestParenting01NEWT
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.newt.parenting.TestParenting02NEWT
+REM scripts\java-win64.bat com.jogamp.opengl.test.junit.newt.TestCloseNewtAWT
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.jogl.caps.TestMultisampleAWT -time 10000
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.jogl.caps.TestMultisampleNEWT -time 10000
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.jogl.acore.TestGLProfile01NEWT -time 2000
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.jogl.awt.TestAWT03GLCanvasRecreate01 -time 2000
-REM scripts\java-win64-dbg.bat com.jogamp.test.junit.jogl.newt.TestSwingAWTRobotUsageBeforeJOGLInitBug411 -time 2000
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.jogl.acore.TestGLProfile01NEWT -time 2000
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.jogl.awt.TestAWT03GLCanvasRecreate01 -time 2000
+REM scripts\java-win64-dbg.bat com.jogamp.opengl.test.junit.jogl.newt.TestSwingAWTRobotUsageBeforeJOGLInitBug411 -time 2000
diff --git a/make/scripts/tests.sh b/make/scripts/tests.sh
index d0250b984..b074fdf13 100644
--- a/make/scripts/tests.sh
+++ b/make/scripts/tests.sh
@@ -67,69 +67,69 @@ function testawt() {
#testnoawt com.jogamp.opengl.JoglVersion $*
#testnoawt com.jogamp.newt.NewtVersion $*
#testnoawt com.jogamp.newt.opengl.GLWindow $*
#testnoawt com.jogamp.test.junit.jogl.acore.TestGLProfile01NEWT $*
#testawt com.jogamp.test.junit.jogl.acore.TestGLProfile01NEWT $*
#testawt com.jogamp.test.junit.jogl.acore.TestSharedContextListNEWT $*
#testnoawt com.jogamp.test.junit.jogl.glsl.TestTransformFeedbackVaryingsBug407NEWT $*
#testnoawt com.jogamp.test.junit.jogl.glsl.TestGLSLSimple01NEWT $*
#testnoawt com.jogamp.test.junit.newt.TestRemoteWindow01NEWT -time 1000000
#testnoawt com.jogamp.test.junit.newt.TestRemoteGLWindows01NEWT -time 1000000
#testawt com.jogamp.test.junit.jogl.demos.gl2.gears.newt.TestGearsNEWT $*
#testawt com.jogamp.test.junit.newt.TestDisplayLifecycle01NEWT
#testawt com.jogamp.test.junit.newt.TestDisplayLifecycle02NEWT
#testawt com.jogamp.test.junit.newt.parenting.TestParenting01NEWT
#testawt com.jogamp.test.junit.newt.parenting.TestParenting02NEWT
#testawt com.jogamp.test.junit.newt.TestScreenMode00NEWT
#testnoawt com.jogamp.test.junit.newt.TestScreenMode01NEWT
#testnoawt com.jogamp.test.junit.newt.TestScreenMode02NEWT
#testawt com.jogamp.test.junit.newt.TestGLWindows01NEWT -time 1000000
#testawt -Djava.awt.headless=true com.jogamp.test.junit.newt.TestGLWindows01NEWT
#testawt com.jogamp.test.junit.newt.TestGLWindows02NEWTAnimated
#
# awt (testawt)
#
#testawt javax.media.opengl.awt.GLCanvas $*
#testawt com.jogamp.test.junit.jogl.awt.TestAWT01GLn $*
#testawt com.jogamp.test.junit.jogl.acore.TestSharedContextListAWT $*
#testawt com.jogamp.test.junit.jogl.awt.TestSwingAWT01GLn
#testawt com.jogamp.test.junit.jogl.awt.TestAWT03GLCanvasRecreate01 $*
#testawt com.jogamp.test.junit.jogl.awt.TestAWT02WindowClosing
#testawt com.jogamp.test.junit.jogl.demos.gl2.gears.TestGearsAWT
#testawt com.jogamp.test.junit.jogl.demos.gl2.gears.TestGearsGLJPanelAWT $*
#testawt com.jogamp.test.junit.jogl.texture.TestTexture01AWT
#
# newt.awt (testawt)
#
-testawt com.jogamp.test.junit.jogl.newt.TestSwingAWTRobotUsageBeforeJOGLInitBug411
-#testawt com.jogamp.test.junit.jogl.demos.gl2.gears.newt.TestGearsNewtAWTWrapper
-#testawt com.jogamp.test.junit.newt.TestEventSourceNotAWTBug
-#testawt com.jogamp.test.junit.newt.TestFocus01SwingAWTRobot
-#testawt com.jogamp.test.junit.newt.TestFocus02SwingAWTRobot
-#testawt com.jogamp.test.junit.newt.TestListenerCom01AWT
-#testawt com.jogamp.test.junit.newt.parenting.TestParenting01aAWT
-#testawt com.jogamp.test.junit.newt.parenting.TestParenting01bAWT
-#testawt com.jogamp.test.junit.newt.parenting.TestParenting01cAWT
-#testawt com.jogamp.test.junit.newt.parenting.TestParenting01cSwingAWT
-#testawt com.jogamp.test.junit.newt.parenting.TestParenting02AWT
-#testawt com.jogamp.test.junit.newt.parenting.TestParenting03AWT
-#testawt com.jogamp.test.junit.newt.parenting.TestParenting03AWT -time 100000
-#testawt com.jogamp.test.junit.newt.parenting.TestParenting03bAWT -time 100000
-#testawt com.jogamp.test.junit.newt.TestCloseNewtAWT
-#testawt com.jogamp.test.junit.jogl.caps.TestMultisampleAWT $*
-#testawt com.jogamp.test.junit.jogl.caps.TestMultisampleNEWT $*
-
-#testawt com.jogamp.test.junit.newt.TestGLWindows02NEWTAnimated $*
-#testawt com.jogamp.test.junit.jogl.newt.TestSwingAWTRobotUsageBeforeJOGLInitBug411 $*
-#testawt com.jogamp.test.junit.newt.parenting.TestParenting01NEWT $*
+testawt com.jogamp.opengl.test.junit.jogl.newt.TestSwingAWTRobotUsageBeforeJOGLInitBug411
+#testawt com.jogamp.opengl.test.junit.jogl.demos.gl2.gears.newt.TestGearsNewtAWTWrapper
+#testawt com.jogamp.opengl.test.junit.newt.TestEventSourceNotAWTBug
+#testawt com.jogamp.opengl.test.junit.newt.TestFocus01SwingAWTRobot
+#testawt com.jogamp.opengl.test.junit.newt.TestFocus02SwingAWTRobot
+#testawt com.jogamp.opengl.test.junit.newt.TestListenerCom01AWT
+#testawt com.jogamp.opengl.test.junit.newt.parenting.TestParenting01aAWT
+#testawt com.jogamp.opengl.test.junit.newt.parenting.TestParenting01bAWT
+#testawt com.jogamp.opengl.test.junit.newt.parenting.TestParenting01cAWT
+#testawt com.jogamp.opengl.test.junit.newt.parenting.TestParenting01cSwingAWT
+#testawt com.jogamp.opengl.test.junit.newt.parenting.TestParenting02AWT
+#testawt com.jogamp.opengl.test.junit.newt.parenting.TestParenting03AWT
+#testawt com.jogamp.opengl.test.junit.newt.parenting.TestParenting03AWT -time 100000
+#testawt com.jogamp.opengl.test.junit.newt.parenting.TestParenting03bAWT -time 100000
+#testawt com.jogamp.opengl.test.junit.newt.TestCloseNewtAWT
+#testawt com.jogamp.opengl.test.junit.jogl.caps.TestMultisampleAWT $*
+#testawt com.jogamp.opengl.test.junit.jogl.caps.TestMultisampleNEWT $*
+
+#testawt com.jogamp.opengl.test.junit.newt.TestGLWindows02NEWTAnimated $*
+#testawt com.jogamp.opengl.test.junit.jogl.newt.TestSwingAWTRobotUsageBeforeJOGLInitBug411 $*
+#testawt com.jogamp.opengl.test.junit.newt.parenting.TestParenting01NEWT $*
#testawt $*
#testawt com.jogamp.test.junit.jogl.acore.TestGLProfile01NEWT $*
#testawt com.jogamp.test.junit.jogl.awt.TestAWT03GLCanvasRecreate01 -time 2000
#testawt com.jogamp.test.junit.jogl.newt.TestSwingAWTRobotUsageBeforeJOGLInitBug411
$spath/count-edt-start.sh java-run.log
@@ -67,69 +67,69 @@ function testawt() {
#testnoawt com.jogamp.newt.NewtVersion $*
#testnoawt com.jogamp.newt.opengl.GLWindow $*
-#testnoawt com.jogamp.test.junit.jogl.acore.TestGLProfile01NEWT $*
-#testawt com.jogamp.test.junit.jogl.acore.TestGLProfile01NEWT $*
-#testawt com.jogamp.test.junit.jogl.acore.TestSharedContextListNEWT $*
-#testnoawt com.jogamp.test.junit.jogl.glsl.TestTransformFeedbackVaryingsBug407NEWT $*
-#testnoawt com.jogamp.test.junit.jogl.glsl.TestGLSLSimple01NEWT $*
-#testnoawt com.jogamp.test.junit.newt.TestRemoteWindow01NEWT -time 1000000
-#testnoawt com.jogamp.test.junit.newt.TestRemoteGLWindows01NEWT -time 1000000
-#testawt com.jogamp.test.junit.jogl.demos.gl2.gears.newt.TestGearsNEWT $*
-#testawt com.jogamp.test.junit.newt.TestDisplayLifecycle01NEWT
-#testawt com.jogamp.test.junit.newt.TestDisplayLifecycle02NEWT
-#testawt com.jogamp.test.junit.newt.parenting.TestParenting01NEWT
-#testawt com.jogamp.test.junit.newt.parenting.TestParenting02NEWT
-#testawt com.jogamp.test.junit.newt.TestScreenMode00NEWT
-#testnoawt com.jogamp.test.junit.newt.TestScreenMode01NEWT
-#testnoawt com.jogamp.test.junit.newt.TestScreenMode02NEWT
-#testawt com.jogamp.test.junit.newt.TestGLWindows01NEWT -time 1000000
-#testawt -Djava.awt.headless=true com.jogamp.test.junit.newt.TestGLWindows01NEWT
-#testawt com.jogamp.test.junit.newt.TestGLWindows02NEWTAnimated
+#testnoawt com.jogamp.opengl.test.junit.jogl.acore.TestGLProfile01NEWT $*
+#testawt com.jogamp.opengl.test.junit.jogl.acore.TestGLProfile01NEWT $*
+#testawt com.jogamp.opengl.test.junit.jogl.acore.TestSharedContextListNEWT $*
+#testnoawt com.jogamp.opengl.test.junit.jogl.glsl.TestTransformFeedbackVaryingsBug407NEWT $*
+#testnoawt com.jogamp.opengl.test.junit.jogl.glsl.TestGLSLSimple01NEWT $*
+#testnoawt com.jogamp.opengl.test.junit.newt.TestRemoteWindow01NEWT -time 1000000
+#testnoawt com.jogamp.opengl.test.junit.newt.TestRemoteGLWindows01NEWT -time 1000000
+#testawt com.jogamp.opengl.test.junit.jogl.demos.gl2.gears.newt.TestGearsNEWT $*
+#testawt com.jogamp.opengl.test.junit.newt.TestDisplayLifecycle01NEWT
+#testawt com.jogamp.opengl.test.junit.newt.TestDisplayLifecycle02NEWT
+#testawt com.jogamp.opengl.test.junit.newt.parenting.TestParenting01NEWT
+#testawt com.jogamp.opengl.test.junit.newt.parenting.TestParenting02NEWT
+#testawt com.jogamp.opengl.test.junit.newt.TestScreenMode00NEWT
+#testnoawt com.jogamp.opengl.test.junit.newt.TestScreenMode01NEWT
+#testnoawt com.jogamp.opengl.test.junit.newt.TestScreenMode02NEWT
+#testawt com.jogamp.opengl.test.junit.newt.TestGLWindows01NEWT -time 1000000
+#testawt -Djava.awt.headless=true com.jogamp.opengl.test.junit.newt.TestGLWindows01NEWT
+#testawt com.jogamp.opengl.test.junit.newt.TestGLWindows02NEWTAnimated
#
# awt (testawt)
@@ -67,69 +67,69 @@ function testawt() {
#
#testawt javax.media.opengl.awt.GLCanvas $*
-#testawt com.jogamp.test.junit.jogl.awt.TestAWT01GLn $*
-#testawt com.jogamp.test.junit.jogl.acore.TestSharedContextListAWT $*
-#testawt com.jogamp.test.junit.jogl.awt.TestSwingAWT01GLn
-#testawt com.jogamp.test.junit.jogl.awt.TestAWT03GLCanvasRecreate01 $*
-#testawt com.jogamp.test.junit.jogl.awt.TestAWT02WindowClosing
-#testawt com.jogamp.test.junit.jogl.demos.gl2.gears.TestGearsAWT
-#testawt com.jogamp.test.junit.jogl.demos.gl2.gears.TestGearsGLJPanelAWT $*
-#testawt com.jogamp.test.junit.jogl.texture.TestTexture01AWT
+#testawt com.jogamp.opengl.test.junit.jogl.awt.TestAWT01GLn $*
+#testawt com.jogamp.opengl.test.junit.jogl.acore.TestSharedContextListAWT $*
+#testawt com.jogamp.opengl.test.junit.jogl.awt.TestSwingAWT01GLn
+#testawt com.jogamp.opengl.test.junit.jogl.awt.TestAWT03GLCanvasRecreate01 $*
+#testawt com.jogamp.opengl.test.junit.jogl.awt.TestAWT02WindowClosing
+#testawt com.jogamp.opengl.test.junit.jogl.demos.gl2.gears.TestGearsAWT
+#testawt com.jogamp.opengl.test.junit.jogl.demos.gl2.gears.TestGearsGLJPanelAWT $*
+#testawt com.jogamp.opengl.test.junit.jogl.texture.TestTexture01AWT
#
# newt.awt (testawt)
@@ -67,69 +67,69 @@ function testawt() {
#testawt $*
-#testawt com.jogamp.test.junit.jogl.acore.TestGLProfile01NEWT $*
-#testawt com.jogamp.test.junit.jogl.awt.TestAWT03GLCanvasRecreate01 -time 2000
-#testawt com.jogamp.test.junit.jogl.newt.TestSwingAWTRobotUsageBeforeJOGLInitBug411
+#testawt com.jogamp.opengl.test.junit.jogl.acore.TestGLProfile01NEWT $*
+#testawt com.jogamp.opengl.test.junit.jogl.awt.TestAWT03GLCanvasRecreate01 -time 2000
+#testawt com.jogamp.opengl.test.junit.jogl.newt.TestSwingAWTRobotUsageBeforeJOGLInitBug411
$spath/count-edt-start.sh java-run.log